@@ -133,6 +133,12 @@ enum {
 	PLOTLEGEND_MENU_OUTSIDE
 };
 
+#ifdef _WIN32
+void create_systray_icon();
+void destroy_systray_icon();
+#endif
+bool has_systray_icon();
+void test_border(void);
 void set_custom_buttons(void);
 void update_custom_buttons(int index = -1);
 void update_custom_buttons_edit(int index = -1, bool update_label_entry = true);
